<%include file="/pageheader.html"/>

# Help Index

## General

About Kaithem
Online Documentation Wiki License/Legal
General Documentation
Math constants, knots, and more

## Details

The kaithem.api module
The Widgets API
Generic Device Abstraction
JACK/Mixing Board
Tag Points
Using MIDI inputs
JACK support and mixing board
Change Log
Save file formats(WIP)

## Licenses

GPLv3
LGPLv3
Apache 2.0

## Online

Python 3 docs
<%include file="/pagefooter.html"/>